@@ -28,7 +28,7 @@
 //#include <QDebug>
 
 Widget::Widget()
-    : QWidget(0, Qt::FramelessWindowHint), timerCookie(0), alarmSeconds(0), error(false)
+    : QWidget(0, Qt::FramelessWindowHint), alarmSeconds(0), error(false)
 {
 
      // Get required atoms
@@ -140,7 +140,6 @@ void Widget::fireNextTimerEvent()
 void Widget::reset()
 {
     countdownTimer->stop();
-    timerCookie = 0;
     alarmSeconds = 0;
     alarmTime.setTime_t(0);
     updateTimeLabel(alarmSeconds);
